@@ -10,7 +10,7 @@ from skimage.feature import peak_local_max
 from skimage.draw import disk
 from scipy.signal import find_peaks
 from IPython.display import clear_output
-#import collections
+import threading
 
 import pkg_resources
 import sys
